import React, {useEffect, useState} from "react";
import {BrigadeEntity} from "../../types/BrigadeEntity";
import {Link} from "react-router-dom";
interface User {
    id: string;
    name:string;
    description: string;
    dateOfCreation: string;
    size: string
}
interface Props {
    setUser: (s:User)=>void
}

export const Brigade = (props:Props) => {
    const [brigadeList, setBrigadeList] = useState<BrigadeEntity[] | null>( null);
    const [error, setError] = useState<string | null>(null)


    useEffect(() => {
        (async () => {
                try {
                    const res = await fetch('http://localhost:3001/brigade');
                    const dane = await res.json();
                    if(dane.statusCode === 404){
                        setError('Wczytywanie nie powiodło się');
                    }
                    setBrigadeList(dane)
                }catch (e) {
                }
            }
        )();
    }, []);
    if(error){
        return <p>Error {error}</p>
    }

    if(brigadeList === null){

        return <p>Wczytujemy......</p>
    }

    return (
        <div className=" rounded overflow-hidden shadow-lg">
            <div className="flex justify-end ">
                <Link
                    to={'/brygady/new'}
                    className=" bg-transparent hover:bg-blue-500 text-blue-700 font-semibold hover:text-white py-2 px-4 border border-blue-500 hover:border-transparent rounded text-sm mb-2"
                >
                    Dodaj brygade
                </Link>
            </div>



            <div className="shadow-md">
                <table className="w-full text-sm text-left text-gray-500 dark:text-gray-400 ">
                    <thead className="text-xs text-gray-700 uppercase bg-gray-50 dark:bg-gray-700 dark:text-gray-400">
                    <tr>
                        <th scope="col" className="px-6 py-3 ">
                            Nazwa
                        </th>
                        <th scope="col" className="px-6 py-3">
                            Opis
                        </th>
                        <th scope="col" className="px-6 py-3">
                            Data utworzenia
                        </th>
                        <th scope="col" className="px-6 py-3">
                            Ilość osub w brygadzie
                        </th>
                        <th scope="col" className="px-6 py-3">
                            Akcja
                        </th>
                    </tr>
                    </thead>
                    <tbody>
                        {brigadeList?.map((walue) =>
                            <tr
                                key={walue.id}
                                className="bg-white border-b dark:bg-gray-800 dark:border-gray-700 hover:bg-gray-50">
                                <th scope="row"
                                    className="px-6 py-4 font-medium text-gray-900 dark:text-white whitespace-nowrap ">
                                    {walue.name}
                                </th>
                                <td className="px-6 py-4">
                                    {walue.description}
                                </td>
                                <td className="px-6 py-4">
                                    {walue.dateOfCreation}
                                </td>
                                <td className="px-6 py-4">
                                    {walue.size}
                                </td>
                                <div className={'flex'}>
                                    <Link
                                        to={`/brygady/edit/${walue.id}`}

                                        className=" bg-green-200 hover:bg-green-500 text-green-700 font-semibold hover:text-white py-2 px-4 border border-green-500 hover:border-transparent rounded text-sm m-2"
                                        onClick={()=>{
                                            props.setUser(walue)
                                        }}
                                    >
                                        Edytuj
                                    </Link>
                                    <Link
                                        to={"/brygady"}
                                        onClick={async ()=>{
                                            const newBrigadeList:any = []
                                            await fetch(`http://localhost:3001/brigade/${walue.id}`, {
                                                method: 'DELETE'})
                                            // eslint-disable-next-line array-callback-return
                                            brigadeList?.map(brigade=>{
                                                if(!(walue.id===brigade.id)){
                                                    newBrigadeList.push(brigade)
                                                }
                                            })
                                            setBrigadeList(newBrigadeList)
                                        }}
                                        className=" bg-red-200 hover:bg-red-500 text-red-700 font-semibold hover:text-white py-2 px-4 border border-red-500 hover:border-transparent rounded text-sm m-2">
                                        Usuń
                                    </Link>

                                </div>

                            </tr>
                        )}

                    </tbody>
                </table>
            </div>
        </div>
    )
}